/** \file main_tx.c
* \brief TX-section
* \brief This program illustrates the usage of CW
*
*/

//Copyright 2015 ON Semiconductor.  All rights reserved.  This software and/or related material is licensed by ON Semiconductor under limited terms and conditions.  The 
//terms and conditions pertaining to the software and/or related material are available at http://www.onsemi.com/site/pdf/ONSEMI_T&C.pdf (“ON Semiconductor Standard Terms 
//and Conditions of Sale, Section 8 Software”).  Do not use this software and/or related material unless you have carefully read and you agree to the limited terms and 
//conditions. By using this software and/or related material, you agree to the limited terms and conditions.


#include <ax8052f131.h>
#include <libmf.h>
#include <libmfradio.h>
#include <libmflcd.h>

#include "global.h"

uint8_t __xdata pllrange;   	   	// Synthesizer range




/************************************************************************/
/************************************************************************/
/* Initialization Routines                                              */
/************************************************************************/
/************************************************************************/



uint8_t _sdcc_external_startup(void)
{
    PORTC = 0x03;
    PORTB = 0x3c;
    PORTA = 0x24;
    PORTR = 0x40;

    DIRC = 0x07;
    DIRB = 0x03;
    DIRR = 0x15;

    SPCLKSRC = 0xD8;
    SPMODE = 0x01;
    SPSHREG;

    RADIOMUX = 0x47;
    RADIOACC = 0x00;

    EIE = 0x00;
    E2IE = 0x00;
    IE = 0x10;  // Enable radio IRQ

    return 0;
}


void stop_with_error(const __code char *str)
{
    lcd_setpos(0);
    lcd_waitshort();
    lcd_writestr(str);
    while(1)
        enter_sleep();
}



// ------------------------------------------------------------------------
// ------------------------------------------------------------------------




void init_ax5031(void)
{

    // register settings are calculated by the AXEVK software
    // The code snippets window was pasted into this routine
    // A few registers were added by hand, see comments.

    AX5031_PWRMODE = 0x00;   	   // mode OFF
    AX5031_PINCFG1 = 0xF0;
    AX5031_PINCFG3 = 0x80; 			// required for module 7.3

    // ---------------------------------------------------------
    //
    // copy from EVK code snippets

#include "ax5031-cw.h"

    // ---------------------------------------------------------
    //

    // AX5031 changes from default

//    AX5031_RFMISC = 0xB0;   	   	   // LOCURST=1

} // end init_ax5031


uint8_t pllrange_ax5031(uint8_t range)    	   	// range the AX5031 Synthesizer
{
    uint8_t r;
    uint8_t rcount=0;

    AX5031_PWRMODE = 0x00;
    AX5031_PWRMODE = 0x0C;   	// set mode synth TX

    r=range;
    AX5031_PLLRANGING = 0x10 | (range & 0x0f);  // start value typical 0x08

    do
    {
        delay(2000);
        r=AX5031_PLLRANGING;
        rcount++;
        if (rcount>10) stop_with_error("PLL range\nERROR");
    }
    while ((r&0x10)!=0);

    r=r&0x0F;
    return r;
}

void set_ax5031_idle(void) __reentrant   	// put the program and the AX5031 into idle mode
{
    AX5031_IRQMASK = 0x00;   // disable AX5031 interrupts
    EA = 0;   	   	   	   // disable 8051 IRQ
    AX5031_PWRMODE = 0x00;  // REF=ON, OSC=ON

}  // end set_ax5031_idle







// switch constant wave on for testing
void set_cw_ax5031(void)
{
    AX5031_PWRMODE = 0x0D;  // TX wire mode
    AX5031_MODULATION = 0x5e;   // Set an FSK mode

    AX5031_TXBITRATEHI = 0x0;
    AX5031_TXBITRATEMID = 0x0;
    AX5031_TXBITRATELO = 0x0;

    AX5031_FSKDEV2 = 0x00;
    AX5031_FSKDEV1 = 0x00;
    AX5031_FSKDEV0 = 0x00;

    AX5031_TXPWR = 0x0F;   	// Max power
}


void set_clk_ax5031(uint8_t clock)   	   // switch sysclk on for testing
{

    // spi_write(AX5031_PWRMODE, 0x05);     // ref and osc ON
    // delay(10000);   	   	   	   	// wait for oscillator to be settled
    if (clock==OFF)
        AX5031_PINCFG1 = 0xD0;
    if (clock==16)
    {
        AX5031_PINCFG1 = 0xD3;
    }

}





// ----------------------------------------------------------------------
//
//   Main



void main (void)
{

#ifndef SDCC
    _sdcc_external_startup();
#endif
    flash_apply_calibration();

    lcd_init();
    lcd_setpos(0);
    lcd_waitshort();

    ax5031_comminit();

    if (ax5031_reset())
        stop_with_error("No AX5031 found");


    init_ax5031();
    set_clk_ax5031(OFF);
    pllrange = pllrange_ax5031(0x08);



    lcd_writestr("AX5031 TX CW");

    set_cw_ax5031();

    while (1);


}    // end main





